@@ -29,7 +29,7 @@ async def _main(args):
     disable_stdout_buffering()
     ebus = create_ebus(args)
     await async_load_msgdefs(ebus, args)
-    msgdefs = ebus.msgdefs.resolve(args.patterns.split(";"))
+    msgdefs = ebus.msgdefs.resolve(args.patterns)
     if args.defaultprio:
         msgdefs.set_defaultprio(args.defaultprio)
     print(f"Observing {msgdefs.summary()}")
