@@ -3,6 +3,7 @@ import asyncio
 import logging
 
 from .const import DEFAULT_HOST, DEFAULT_PORT, DEFAULT_TIMEOUT
+from .exceptions import CommandError, Shutdown
 from .util import repr_
 
 _LOGGER = logging.getLogger(__name__)
@@ -16,6 +17,7 @@ class Connection:
         host (str): Hostname or IP
         port (int): Port
         autoconnect (bool): Automatically connect and re-connect
+        timeout (int): Connection Timeout
     """
 
     def __init__(self, host=DEFAULT_HOST, port=DEFAULT_PORT, autoconnect=False, timeout=DEFAULT_TIMEOUT):
@@ -192,13 +194,3 @@ class Connection:
         else:
             result = await task
         return result
-
-
-class CommandError(RuntimeError):
-
-    """Command Error raised in case of EBUSD error, typically if the response starts with `ERR:`"""
-
-
-class Shutdown(ConnectionError):
-
-    """EBUS Shutdown."""
