@@ -595,9 +595,11 @@ class DateType(Type):
     '-.-.-'
     """
 
+    _NONE = "-.-.-"
+
     def decode(self, value):
         """Decode `value`."""
-        if value != "-.-.-":
+        if value != self._NONE:
             return datetime.datetime.strptime(value, "%d.%m.%Y").date()
         else:
             return None
@@ -609,7 +611,7 @@ class DateType(Type):
         if value is not None:
             return f"{value.day}.{value.month}.{value.year}"
         else:
-            return "-.-.-"
+            return self._NONE
 
     @property
     def comment(self):
@@ -631,12 +633,19 @@ class TimeType(Type):
     Time(23, 59, 59)
     >>> t.decode('-:-:-') is None
     True
-
+    >>> t.encode('23:59:59')
+    '23:59:59'
+    >>> t.encode(Time(23, 59, 59))
+    '23:59:59'
+    >>> t.encode(None)
+    '-:-:-'
     """
 
+    _NONE = "-:-:-"
+
     def decode(self, value):
         """Decode `value`."""
-        if value != "-:-:-":
+        if value != self._NONE:
             tstamp = datetime.datetime.strptime(value, "%H:%M:%S")
             return Time(tstamp.hour, tstamp.minute, tstamp.second)
         else:
@@ -649,7 +658,7 @@ class TimeType(Type):
         if value is not None:
             return f"{value.hour:02d}:{value.minute:02d}:{value.second:02d}"
         else:
-            return "-:-"
+            return self._NONE
 
     @property
     def comment(self):
@@ -676,6 +685,12 @@ class HourMinuteType(TimeType):
     HourMinute(23, 59)
     >>> t.decode('-:-') is None
     True
+    >>> t.encode('23:59')
+    '23:59'
+    >>> t.encode(HourMinute(23, 59))
+    '23:59'
+    >>> t.encode(None)
+    '-:-'
 
     With Minimum Resolution
 
@@ -694,8 +709,20 @@ class HourMinuteType(TimeType):
     Traceback (most recent call last):
       ...
     ValueError: Minute of 23:51 must be multiple of 10
+    >>> t.encode('23:50')
+    '23:50'
+    >>> t.encode(HourMinute(23, 50))
+    '23:50'
+    >>> t.encode(HourMinute(23, 52))
+    Traceback (most recent call last):
+      ...
+    ValueError: Minute of 23:52 must be multiple of 10
+    >>> t.encode(None)
+    '-:-'
     """
 
+    _NONE = "-:-"
+
     def __init__(self, minres=None):
         super().__init__()
         self._minres = minres
@@ -710,7 +737,7 @@ class HourMinuteType(TimeType):
 
     def decode(self, value):
         """Decode `value`."""
-        if value != "-:-":
+        if value != self._NONE:
             value = datetime.datetime.strptime(value, "%H:%M")
             value = HourMinute(value.hour, value.minute)
             if self._minres and (value.minute % self._minres) != 0:
@@ -728,7 +755,7 @@ class HourMinuteType(TimeType):
                 raise ValueError(f"Minute of {value} must be multiple of {self._minres}")
             return f"{value.hour:02d}:{value.minute:02d}"
         else:
-            return "-:-"
+            return self._NONE
 
     @property
     def comment(self):
@@ -741,23 +768,44 @@ class HourMinuteType(TimeType):
 
 class DateTimeType(Type):
 
-    """Date Time."""
+    """
+    Date Time.
+
+
+    >>> t = DateTimeType()
+    >>> t
+    DateTimeType()
+    >>> t.comment
+    'DAY.MONTH.YEAR HOUR:MINUTE:SECOND'
+    >>> t.decode('30.12.2020 23:59:59')
+    DateTime(2020, 12, 30, 23, 59, 59)
+    >>> t.decode('-.-.- -:-:-') is None
+    True
+    >>> t.encode('30.12.2020 23:59:59')
+    '30.12.2020 23:59:59'
+    >>> t.encode(DateTime(2020, 12, 30, 23, 59, 59))
+    '30.12.2020 23:59:59'
+    >>> t.encode(None)
+    '-.-.- -:-:-'
+    """
+
+    _NONE = "-.-.- -:-:-"
 
     def decode(self, value):
         """Decode `value`."""
-        if value != "-:-:-":
-            return datetime.datetime.strptime(value, "%d.%m.%Y %H:%M:%S")
+        if value != self._NONE:
+            return DateTime.strptime(value, "%d.%m.%Y %H:%M:%S")
         else:
             return None
 
     def encode(self, value):
         """Encode `value`."""
         if isinstance(value, str):
-            value = datetime.datetime.strptime(value, "%d.%m.%Y %H:%M:%S")
+            value = DateTime.strptime(value, "%d.%m.%Y %H:%M:%S")
         if value is not None:
             return f"{value.day}.{value.month}.{value.year} {value.hour:02d}:{value.minute:02d}:{value.second:02d}"
         else:
-            return "-.-.- -:-:-"
+            return self._NONE
 
     @property
     def comment(self):
@@ -766,7 +814,17 @@ class DateTimeType(Type):
 
 
 class WeekdayType(Type):
-    """Weekday Type."""
+    """
+    Weekday Type.
+
+    >>> t = WeekdayType()
+    >>> t.comment
+    ''
+    >>> t.decode('a')
+    'a'
+    >>> t.encode('a')
+    'a'
+    """
 
     def decode(self, value):
         """Decode `value`."""
@@ -784,7 +842,17 @@ class WeekdayType(Type):
 
 class PinType(Type):
 
-    """Pin."""
+    """
+    Pin.
+
+    >>> t = PinType()
+    >>> t.comment
+    ''
+    >>> t.decode('a')
+    'a'
+    >>> t.encode('a')
+    'a'
+    """
 
     def decode(self, value):
         """Decode `value`."""
@@ -800,9 +868,33 @@ class PinType(Type):
         return ""
 
 
+class DateTime(datetime.datetime):
+
+    """
+    DateTime.
+
+    >>> t = DateTime(2020, 12, 31, 23, 59, 59)
+    >>> t
+    DateTime(2020, 12, 31, 23, 59, 59)
+    >>> str(t)
+    '31.12.2020 23:59:59'
+    """
+
+    def __str__(self):
+        return self.strftime("%d.%m.%Y %H:%M:%S")
+
+
 class Time(datetime.time):
 
-    """Time."""
+    """
+    Time.
+
+    >>> t = Time(23, 59, 59)
+    >>> t
+    Time(23, 59, 59)
+    >>> str(t)
+    '23:59:59'
+    """
 
     def __str__(self):
         return self.strftime("%H:%M:%S")
@@ -810,7 +902,15 @@ class Time(datetime.time):
 
 class HourMinute(datetime.time):
 
-    """Time without Seconds."""
+    """
+    Time without Seconds.
+
+    >>> t = HourMinute(23, 59)
+    >>> t
+    HourMinute(23, 59)
+    >>> str(t)
+    '23:59'
+    """
 
     def __str__(self):
         return self.strftime("%H:%M")
